@@ -1,6 +1,7 @@
 import sys
 import uuid
 from typing import Any
+from pythautomata.abstract.finite_automaton import FiniteAutomaton
 
 from pythautomata.base_types.moore_state import MooreState
 from pythautomata.base_types.alphabet import Alphabet
@@ -9,10 +10,11 @@ from pythautomata.base_types.symbol import Symbol
 
 from pythautomata.exceptions.unknown_symbols_exception import UnknownSymbolsException
 from pythautomata.exceptions.non_deterministic_states_exception import NonDeterministicStatesException
-from pythautomata.model_exporters.dot_exporting_mm_strategy import DotExportingMMStrategy
-from pythautomata.model_exporters.standard_dot_exporting_mm_strategy import StandardDotMMExportingStrategy
+from pythautomata.model_exporters.standard_exporters.moore_standard_dot_exporting_strategy import MooreStandardDotExportingStrategy
+from pythautomata.model_exporters.dot_exporters.moore_dot_exporting_strategy import MooreDotExportingStrategy
 
-class MooreMachineAutomaton():
+
+class MooreMachineAutomaton(FiniteAutomaton):
     """
     Implementation of Moore Machines.
 
@@ -33,19 +35,21 @@ class MooreMachineAutomaton():
     Link del artículo: https://arxiv.org/pdf/1605.07805.pdf
     """
 
-    def __init__(self, input_alphabet: Alphabet, output_alphabet: Alphabet, 
-                initial_state: MooreState, states: set[MooreState],
-                comparator, name: str = None,
-                exportingStrategies: list = [DotExportingMMStrategy(), StandardDotMMExportingStrategy()],
-                hole: MooreState = MooreState('\u22A5')):
-        
+    def __init__(self, input_alphabet: Alphabet, output_alphabet: Alphabet,
+                 initial_state: MooreState, states: set[MooreState],
+                 comparator, name: str = None,
+                 exportingStrategies: list = [
+                     MooreDotExportingStrategy(), MooreStandardDotExportingStrategy()],
+                 hole: MooreState = MooreState('\u22A5')):
+
         self.states = states
         for state in self.states:
             self._verify_state(state, input_alphabet, output_alphabet)
             state.add_hole_transition(hole)
 
-        self._name = 'Moore Machine - ' + str(uuid.uuid4().hex) if name is None else name
-        self._input_alphabet = input_alphabet
+        self._name = 'Moore Machine - ' + \
+            str(uuid.uuid4().hex) if name is None else name
+        self._alphabet = input_alphabet
         self._output_alphabet = output_alphabet
         self.initial_state = initial_state
         self._set_hole(hole)
@@ -53,6 +57,10 @@ class MooreMachineAutomaton():
         self._comparator = comparator
         self._actual_state = initial_state
 
+    @FiniteAutomaton.output_alphabet.getter
+    def output_alphabet(self):
+        return self._output_alphabet
+
     def step(self, symbol):
         self._actual_state = self._actual_state.next_state_for(symbol)
 
@@ -61,12 +69,15 @@ class MooreMachineAutomaton():
     def reset(self):
         self._actual_state = self.initial_state
 
-    def last_symbol(self, sequence: Sequence) -> Symbol: 
+    def last_symbol(self, sequence: Sequence) -> Symbol:
         actual_state = self.initial_state
         for symbol in sequence.value:
             actual_state = actual_state.next_state_for(symbol)
         return actual_state.value
 
+    def process_query(self, sequence: Sequence) -> Symbol:
+        return self.last_symbol(sequence)
+
     def transduce(self, sequence: Sequence) -> Sequence:
         actual_state = self.initial_state
         output = Sequence()
@@ -93,13 +104,13 @@ class MooreMachineAutomaton():
                 strategy.export(self, path)
             except:
                 print("Unexpected exception when exporting " +
-                str(self._name) + ": " + str(sys.exc_info()[0]))
+                      str(self._name) + ": " + str(sys.exc_info()[0]))
 
     def _set_hole(self, hole: MooreState) -> None:
         self._hole = hole
         # hole's hole state is itself
         self._hole.add_hole_transition(self.hole)
-    
+
     def _verify_state(self, state: MooreState, alphabet: Alphabet, outputAlphabet: Alphabet) -> None:
         self._verify_symbols_in_output_alphabet(state, outputAlphabet)
         self._verify_transition_symbols_in_alphabet(
@@ -110,7 +121,7 @@ class MooreMachineAutomaton():
             None:
         if not all(symbol in alphabet for symbol in transitions):
             raise UnknownSymbolsException()
-    
+
     def _verify_symbols_in_output_alphabet(self, state: MooreState, outputAlphabet: Alphabet) -> \
             None:
         if not state.value in outputAlphabet:
